==> geolatte-geom-1.3.0-sources.jar: org/geolatte/geom/codec/db/sqlserver/GeometryCollectionSqlServerDecoder.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2013 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.codec.db.sqlserver;

import org.geolatte.geom.Geometry;
import org.geolatte.geom.GeometryCollection;

import java.util.List;

import static org.geolatte.geom.Geometries.mkGeometryCollection;

/**
 * <code>Decoder</code> for GeometryCollections.
 *
 * @Author Karel Maesen
 */
class GeometryCollectionSqlServerDecoder extends AbstractGeometryCollectionSqlServerDecoder {


	@Override
	protected OpenGisType getOpenGisType() {
		return OpenGisType.GEOMETRYCOLLECTION;
	}

    @Override
    protected GeometryCollection<?, Geometry<?>> createGeometry(List geometries, SqlServerGeometry nativeGeom) {
        return mkGeometryCollection(geometries);
    }


}

==> geolatte-geom-1.6.0-sources.jar: org/geolatte/geom/codec/db/sqlserver/GeometryCollectionSqlServerDecoder.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2013 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.codec.db.sqlserver;

import org.geolatte.geom.Geometry;
import org.geolatte.geom.AbstractGeometryCollection;

import java.util.List;

import static org.geolatte.geom.Geometries.mkGeometryCollection;

/**
 * <code>Decoder</code> for GeometryCollections.
 *
 * @Author Karel Maesen
 */
class GeometryCollectionSqlServerDecoder extends AbstractGeometryCollectionSqlServerDecoder {


	@Override
	protected OpenGisType getOpenGisType() {
		return OpenGisType.GEOMETRYCOLLECTION;
	}

    @Override
    protected AbstractGeometryCollection<?, Geometry<?>> createGeometry(List geometries, SqlServerGeometry nativeGeom) {
        return mkGeometryCollection(geometries);
    }


}
